@@ -132,10 +132,11 @@ struct SheetMetadata {
 
 #[derive(Serialize, Deserialize)]
 struct MetadataStruct {
-    filename:   String,
-    format:     String,
-    num_sheets: usize,
-    sheet:      Vec<SheetMetadata>,
+    filename:           String,
+    canonical_filename: String,
+    format:             String,
+    num_sheets:         usize,
+    sheet:              Vec<SheetMetadata>,
 }
 
 struct RequestedRange {
@@ -180,8 +181,8 @@ impl RequestedRange {
         Ok(RequestedRange {
             start: (start_row.unwrap_or(0), start_col.unwrap_or(0)),
             end:   (
-                end_row.unwrap_or((worksheet_size.0 as u32) - 1),
-                end_col.unwrap_or((worksheet_size.1 as u32) - 1),
+                end_row.unwrap_or_else(|| (worksheet_size.0 as u32).saturating_sub(1)),
+                end_col.unwrap_or_else(|| (worksheet_size.1 as u32).saturating_sub(1)),
             ),
         })
     }
@@ -198,6 +199,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         .and_then(std::ffi::OsStr::to_str)
         .unwrap_or_default()
         .to_string();
+    let canonical_filename = sce.canonicalize().unwrap_or_default().display().to_string();
     let format = sce
         .extension()
         .and_then(std::ffi::OsStr::to_str)
@@ -256,16 +258,16 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         }
     };
 
-    // use with_capacity to minimize reallocation
-    let mut record = csv::StringRecord::with_capacity(200, 20);
-
     if metadata_mode != MetadataMode::None {
         let mut excelmetadata_struct = MetadataStruct {
             filename,
+            canonical_filename,
             format,
             num_sheets,
             sheet: vec![],
         };
+        let mut metadata_record;
+
         for (i, sheet_name) in sheet_vec.iter().enumerate() {
             let range = if let Some(result) = workbook.worksheet_range_at(i) {
                 match result {
@@ -355,9 +357,9 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                     "unsafe_headers_count",
                     "duplicate_headers_count",
                 ]);
-                record = csv::StringRecord::from(metadata_fields);
+                metadata_record = csv::StringRecord::from(metadata_fields);
 
-                wtr.write_record(&record)?;
+                wtr.write_record(&metadata_record)?;
 
                 for sheetmetadata in excelmetadata_struct.sheet {
                     let metadata_values = vec![
@@ -372,9 +374,9 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                         sheetmetadata.unsafe_headers_count.to_string(),
                         sheetmetadata.duplicate_headers_count.to_string(),
                     ];
-                    record = csv::StringRecord::from(metadata_values);
+                    metadata_record = csv::StringRecord::from(metadata_values);
 
-                    wtr.write_record(&record)?;
+                    wtr.write_record(&metadata_record)?;
                 }
                 wtr.flush()?;
             }
@@ -470,6 +472,11 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
             parsed_range.start.0, parsed_range.start.1
         );
         info!("Range end: {} {}", parsed_range.end.0, parsed_range.end.1);
+        if parsed_range.start < range.start().unwrap_or((0, 0))
+            || parsed_range.end > range.end().unwrap_or((0, 0))
+        {
+            return fail_clierror!("Cannot retrieve range {requested_range}: larger than sheet");
+        }
         range = range.range(parsed_range.start, parsed_range.end);
     }
 
@@ -497,14 +504,16 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         dates_whitelist.sort_unstable();
     }
 
+    let (row_count, col_count) = range.get_size();
+
     // use with_capacity to minimize reallocations
-    let mut trimmed_record = csv::StringRecord::with_capacity(200, 20);
-    let mut date_flag: Vec<bool> = Vec::with_capacity(20);
+    let mut record = csv::StringRecord::with_capacity(500, col_count);
+    let mut trimmed_record = csv::StringRecord::with_capacity(500, col_count);
+    let mut date_flag: Vec<bool> = Vec::with_capacity(col_count);
 
     let mut cell_date_flag: bool = false;
     let mut float_val = 0_f64;
-    let mut float_flag: bool;
-    let mut row_count = 0_usize;
+    let mut float_flag: bool = false;
 
     let date_format = if let Some(df) = args.flag_date_format {
         df
@@ -556,7 +565,6 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                 info!("date_flag: {date_flag:?}");
                 continue;
             }
-            float_flag = false;
             match *cell {
                 DataType::Empty => record.push_field(""),
                 DataType::String(ref s) => record.push_field(s),
@@ -636,6 +644,8 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
                     let mut buffer = itoa::Buffer::new();
                     record.push_field(buffer.format(float_val as i64));
                 }
+                // set the float flag to false, so we don't try to process the next cell as a float
+                float_flag = false;
             }
         }
 
@@ -653,7 +663,6 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
         } else {
             wtr.write_record(&record)?;
         }
-        row_count += 1;
     }
     wtr.flush()?;
 
@@ -662,7 +671,7 @@ pub fn run(argv: &[&str]) -> CliResult<()> {
             "{} {}-column rows exported from \"{sheet}\" sheet",
             // don't count the header in row count
             row_count.saturating_sub(1).separate_with_commas(),
-            record.len().separate_with_commas(),
+            col_count.separate_with_commas(),
         );
         winfo!("{end_msg}");
     }
