@@ -258,7 +258,7 @@ pub fn infer_schema_from_stats(args: &Args, input_filename: &str) -> CliResult<M
         header_string = convert_to_string(header_byte_slice)?;
 
         // grab stats record for current column
-        stats_record = csv_stats.get(i).unwrap().clone().to_record(4);
+        stats_record = csv_stats.get(i).unwrap().clone().to_record(4, false);
 
         if log::log_enabled!(log::Level::Debug) {
             debug!("stats[{header_string}]: {stats_record:?}");
@@ -419,6 +419,7 @@ fn get_stats_records(args: &Args) -> CliResult<(ByteRecord, Vec<Stats>, AHashMap
         flag_select:          crate::select::SelectColumns::parse("").unwrap(),
         flag_everything:      false,
         flag_typesonly:       false,
+        flag_infer_boolean:   false,
         flag_mode:            false,
         flag_cardinality:     true,
         flag_median:          false,
@@ -584,7 +585,7 @@ fn build_low_cardinality_column_selector_arg(
     // identify low cardinality columns
     for i in 0..csv_fields.len() {
         // grab stats record for current column
-        let stats_record = csv_stats.get(i).unwrap().clone().to_record(4);
+        let stats_record = csv_stats.get(i).unwrap().clone().to_record(4, false);
 
         // get Cardinality
         let col_cardinality = match stats_record.get(stats_col_index_map["cardinality"]) {
