@@ -1,12 +1,12 @@
 static USAGE: &str = r#"
-Quickly sniff and infer CSV metadata (delimiter, header row, number of preamble rows,
-quote character, flexible, is_utf8, average record length, number of records, content
-length and estimated number of records if sniffing a URL, file size, number of fields,
+Quickly sniff the first n rows and infer CSV metadata (delimiter, header row, number of
+preamble rows, quote character, flexible, is_utf8, average record length, number of records,
+content length and estimated number of records if sniffing a URL, file size, number of fields,
 field names & data types) using a Viterbi algorithm.
 (https://en.wikipedia.org/wiki/Viterbi_algorithm)
 
-On Linux, `sniff` also acts as a general file type detector using the libmagic library
-and returns the detected mime type, file size and last modified date if the file is not
+On Linux, `sniff` also acts as a general mime type detector using the libmagic library,
+returning the detected mime type, file size and last modified date if the file is not
 a CSV. If --no-infer is enabled, it doesn't even bother to infer the CSV's schema.
 
 On macOS and Windows however, `sniff` is only a CSV dialect detector and does not
@@ -28,16 +28,22 @@ Usage:
     qsv sniff --help
 
 sniff arguments:
-    <input>                  The file to sniff. This can be a local file, stdin 
-                             or a URL (http and https schemes supported).
+    <input>                  The file to sniff. This can be a local file, stdin or a
+                             URL (http and https schemes supported).
 
-                             Note that when input is a URL, sniff will automatically
-                             download the sample to a temporary file and sniff it. It
-                             will create the file using csv::QuoteStyle::NonNumeric
-                             so the sniffed schema may not be the same as the original.
-                             This is done to increase the chances of sniffing the
-                             correct schema.
+                             Note that when input is a URL and is a CSV candidate,
+                             sniff will automatically download a sample to a temporary
+                             file and sniff it.
 
+                             If the file sample is not a CSV, sniff will return as an error
+                             - the detected mime type, file size & last modified date.
+
+                             When --no-infer is enabled, sniff will not bother to infer the
+                             CSV schema and just work as a general mime type detector -
+                             returning the detected mime type, file size and last modified date.
+                             When sniffing a local file, it will scan the file to detect the mime type.
+                             When sniffing a URL, it will only download the first chunk of the file.
+                             
 sniff options:
     --sample <size>          First n rows to sample to sniff out the metadata.
                              When sample size is between 0 and 1 exclusive, 
@@ -86,6 +92,7 @@ use std::{
 use bytes::Bytes;
 use futures::executor::block_on;
 use futures_util::StreamExt;
+#[cfg(any(feature = "feature_capable", feature = "lite"))]
 use indicatif::{HumanBytes, HumanCount, ProgressBar, ProgressDrawTarget, ProgressStyle};
 use qsv_sniffer::{DatePreference, SampleSize, Sniffer};
 use reqwest::Client;
@@ -114,7 +121,6 @@ struct Args {
     flag_timeout:        u16,
     flag_user_agent:     Option<String>,
     flag_stats_types:    bool,
-    #[cfg(all(target_os = "linux", feature = "magic"))]
     flag_no_infer:       bool,
 }
 
@@ -355,13 +361,16 @@ async fn get_file_to_sniff(args: &Args, tmpdir: &tempfile::TempDir) -> CliResult
                 };
 
                 // prep progress bar
+                #[cfg(any(feature = "feature_capable", feature = "lite"))]
                 let show_progress =
                     args.flag_progressbar || util::get_envvar_flag("QSV_PROGRESSBAR");
 
+                #[cfg(any(feature = "feature_capable", feature = "lite"))]
                 let progress = ProgressBar::with_draw_target(
                     Some(total_size.try_into().unwrap_or(u64::MAX)),
                     ProgressDrawTarget::stderr_with_hz(5),
                 );
+                #[cfg(any(feature = "feature_capable", feature = "lite"))]
                 if show_progress {
                     progress.set_style(
                         ProgressStyle::default_bar()
@@ -433,6 +442,8 @@ async fn get_file_to_sniff(args: &Args, tmpdir: &tempfile::TempDir) -> CliResult
                     }
 
                     downloaded = min(downloaded + chunk_len, total_size);
+
+                    #[cfg(any(feature = "feature_capable", feature = "lite"))]
                     if show_progress {
                         progress.inc(chunk_len as u64);
                     }
@@ -453,6 +464,7 @@ async fn get_file_to_sniff(args: &Args, tmpdir: &tempfile::TempDir) -> CliResult
                 }
                 drop(client);
 
+                #[cfg(any(feature = "feature_capable", feature = "lite"))]
                 if show_progress {
                     if snappy_flag {
                         progress.finish_with_message(format!(
@@ -686,6 +698,18 @@ fn cleanup_tempfile(
 pub async fn run(argv: &[&str]) -> CliResult<()> {
     let args: Args = util::get_args(USAGE, argv)?;
 
+    #[cfg(not(target_os = "linux"))]
+    if args.flag_no_infer {
+        return fail_clierror!(
+            "--no-infer is only supported on Linux with the 'magic' feature enabled"
+        );
+    }
+
+    #[cfg(all(target_os = "linux", not(feature = "magic")))]
+    if args.flag_no_infer {
+        return fail_clierror!("--no-infer is only supported when the 'magic' feature is enabled");
+    }
+
     let mut sample_size = args.flag_sample;
     if sample_size < 0.0 {
         if args.flag_json || args.flag_pretty_json {
@@ -729,7 +753,6 @@ pub async fn run(argv: &[&str]) -> CliResult<()> {
             if args.flag_no_infer {
                 let json_result = json!({
                     "title": "sniff mime type",
-                    "detail": format!("File is not a CSV file. Detected mime type: {file_type}"),
                     "meta": {
                         "detected_mime_type": file_type,
                         "size": size,
