@@ -133,6 +133,11 @@ fn main() -> QsvExitCode {
                 .deserialize()
         })
         .unwrap_or_else(|e| e.exit());
+
+    if util::load_dotenv().is_err() {
+        return QsvExitCode::Bad;
+    }
+
     if args.flag_list {
         wout!(concat!("Installed commands:", command_list!()));
         util::log_end(qsv_args, now);
